@@ -2,7 +2,7 @@
 #define SRC_NODE_VERSION_H_
 
 #define NODE_MAJOR_VERSION 6
-#define NODE_MINOR_VERSION 14
+#define NODE_MINOR_VERSION 15
 #define NODE_PATCH_VERSION 1
 
 #define NODE_VERSION_IS_LTS 1
@@ -15,6 +15,10 @@
 #define NODE_STRINGIFY_HELPER(n) #n
 #endif
 
+#ifndef NODE_RELEASE
+#define NODE_RELEASE "node"
+#endif
+
 #ifndef NODE_TAG
 # if NODE_VERSION_IS_RELEASE
 #  define NODE_TAG ""
@@ -57,4 +61,7 @@
  */
 #define NODE_MODULE_VERSION 48 /* Node.js v6.0.0 */
 
+// the NAPI_VERSION provided by this version of the runtime
+#define NAPI_VERSION  3
+
 #endif  // SRC_NODE_VERSION_H_
